==> batchcomputecli-0.0.17.tar.gz: batchcomputecli-0.0.17/src/batchcomputecli/cli.py <==
from terminal import red, gray, bold, magenta, yellow
from .externals.command import Command
from .actions import login, whoami, images, jobs, job, update_job, \
    remove_job, start_job, stop_job, create_job, get_log, \
    submit_job

from .actions.project import create_project, build_project, \
    add_task, remove_task,update_task, debug_task, view_json,remove_dep, add_dep

import os
from . import const

COMMAND = const.COMMAND

CMD = const.CMD

VERSION = const.VERSION

SPLITER = '    %s' % ('-' * 50)

PYTHON_PROJECT_ONLY = red('python project only')

RUN_IN_PROJECT_FOLDER =  yellow('under project folder only')

def __main():
    program.print_help()


program = Command(COMMAND, version=VERSION,
                  title=bold(magenta('AliCloud BatchCompute CLI')),
                  usage="Usage: %s <command> [option]" % COMMAND,
                  func=__main, help_footer=gray('  type "%s [command] -h" for more' % CMD))


# login
cmd_login = Command('login',
                    description='login with Aliyun AccessKey',
                    func=login.login,
                    arguments=['region', 'accessKeyId', 'accessKeySecret'],
                    usage='''Usage: %s login <region|endpoint> [accessKeyId] [accessKeySecret] [option]

  Examples:
     1. %s login cn-qingdao kywj6si2hkdfy9 lasd7f***********=  #login with full params
     2. %s login cn-shenzhen                                   #just change region
     3. %s login batchcompute.cn-shenzhen.aliyuncs.com         #just change endpoint''' % (COMMAND, CMD, CMD, CMD))
program.action(cmd_login)


# whoami
cmd_whoami = Command('me', alias=['who', 'whoami'], description='get login info',
                     detail='show accesskeyId, region or endpoint',
                     func=whoami.get, spliter=SPLITER)
program.action(cmd_whoami)

# images
cmd_images = Command('images', alias=['imgs', 'img'], description='list images', func=images.list)
cmd_images.option('-p, --platform [platform]', 'filter by platform, scope:[All|Linux|Windows],default:All',
                  resolve=images.transform_platform)
program.action(cmd_images)


# jobs
cmd_jobs = Command('jobs', description='list jobs', func=jobs.list)
cmd_jobs.option('-a, --all', 'show all fields')
cmd_jobs.option('-s, --state [state]',
                'filter by State, scope:[All|Waiting|Running|Failed|Finished|Stopped], default:All',
                resolve=jobs.transform_state)
cmd_jobs.option('-o, --order_by [field_name]', 'order by a field')
cmd_jobs.option('-d, --desc [true|false]', 'reverse result array, default: true')
cmd_jobs.option('-l, --limit [number]', 'limit the length of the result',
                resolve=jobs.transform_limit)
cmd_jobs.option('-w, --watch', 'in watching mode, auto refresh every 3 seconds')
program.action(cmd_jobs)

# job
cmd_job = Command('job', description='get job detail, task detail, instance logs',
                  arguments=['job_id', 'task_name', 'instance_id'],
                  usage="""Usage: %s job <job_id> [task_name] [instance_id] [option]

  Examples:
      1. %s job <job_id>                                         #job detail:
      2. %s job <job_id> <task_name>                             #task detail:
      3. %s job <job_id> <task_name> <instance_id> [--limit 10]  #instance log list: """ % (COMMAND, CMD, CMD, CMD),
                  func=job.getDetail)
cmd_job.option('-l, --limit [number]', 'limit the length of the result, only works in instance log list')
cmd_job.option('-w, --watch', 'in watching mode, auto refresh every 3 seconds, it works in job detail and task detail')
program.action(cmd_job)



# get_log
cmd_get_log = Command('get_log', alias=['log'], description='get instance log from oss_path',
                      spliter=SPLITER,
                      arguments=['oss_path'],
                      usage="""Usage: %s get_log <oss_path> [option]

  Examples:
      1. %s get_log oss://mybucket/abc/stdout.0.1443505842        #print log
      2. %s get_log oss://mybucket/abc/stdout.0.1443505842 -f ./  #download
                      """ % (COMMAND, COMMAND, COMMAND),
                      func=get_log.get_log)
cmd_get_log.option('-f, --file [directory or file]', 'download log to local: -f ./')
program.action(cmd_get_log)



# update_job
cmd_update_job = Command('update_job', alias=['update'],
                         description='update job properties, currently support "Priority" only',
                         arguments=['job_id'],
                         usage="Usage: %s update_job <job_id> [option]" % (COMMAND),
                         func=update_job.update_priority)
cmd_update_job.option('-p, --priority [n]', 'update job set priority, scope:[0,1000]',
                      resolve=update_job.transform_priority)
program.action(cmd_update_job)



# remove_job
cmd_remove_job = Command('remove_job', alias=['rm', 'remove'], description='remove a job',
                         arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=remove_job.remove)
cmd_remove_job.option('-y, --yes', 'without confirm', resolve=remove_job.transform_yes)
program.action(cmd_remove_job)


# start_job
cmd_start_job = Command('start_job', alias=['start'], description='start a job',
                        arguments=['job_id'],
                        # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                        func=start_job.start)
program.action(cmd_start_job)


# stop_job
cmd_stop_job = Command('stop_job', alias=['stop'], description='stop a job',
                       arguments=['job_id'],
                       # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                       func=stop_job.stop)
cmd_stop_job.option('-y, --yes', 'without confirm', resolve=stop_job.transform_yes)
program.action(cmd_stop_job)


# submit_job
cmd_create_job = Command('create_job', alias=['create'], description='create job, from a json string or file',
                         spliter=SPLITER,
                         # arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=create_job.create)

cmd_create_job.option('-j, --json [json_string]', 'create a job from a json string: -j "{\\"JobName\\":\"myJob...."',
                      resolve=create_job.transform_json)
cmd_create_job.option('-f, --file [file_path]', 'create a job from json file: -f ./myjob.json',
                      resolve=create_job.transform_file)
program.action(cmd_create_job)


#########################################
########################################

# def project_help():
#     cmd_project.print_help()
#
#
# # cmd_project
# cmd_project = Command('project', alias=['p'], description='project actions, type "bcs p -h" form more',
#                       detail="create, build job project, edit job...",
#                       func=project_help,help_footer=gray('  type "%s p [command] -h" for more' % CMD))
# program.action(cmd_project)



# create_project
cmd_create_project = Command('create_project', alias=['createp','crp'], description='create job project',
                             detail='create job project',
                             arguments=['project_name', 'location'],
                             usage="""Usage: %s create_project|createp|crp <project_name> [location] [option]

  Examples:
    1. %s crp my_project
    2. %s crp my_project ./ -t python """ % (COMMAND, CMD, CMD),
                             func=create_project.create)
cmd_create_project.option('-t, --type [type]', 'project type, scope:[python|java|native],default:python',
                          resolve=create_project.transform_type)
program.action(cmd_create_project)






# build_project
cmd_build_project = Command('build_project', alias=['build'], description='build project, make worker.tar.gz.(%s)' % RUN_IN_PROJECT_FOLDER,
                            usage="""Usage: %s build_project|build [option]""" % (COMMAND),
                            func=build_project.build)
program.action(cmd_build_project)


# submit
cmd_submit_job = Command('submit_job', alias=['submit'], description='upload worker.tar.gz and create a job(%s)' % RUN_IN_PROJECT_FOLDER,
                         spliter=SPLITER,
                         detail="upload worker.tar.gz to PackageUri defined in job.json, and then create a job.(%s)" % RUN_IN_PROJECT_FOLDER,
                         usage="""Usage: %s submit_job|submit [option]

  Example: %s submit""" % (COMMAND, CMD),
                         func=submit_job.submit)
program.action(cmd_submit_job)


# view json
cmd_view_json = Command('view_json', alias=['view', 'v'], description='show job.json in a humanized view.(%s)' % RUN_IN_PROJECT_FOLDER,
                        usage="""Usage: %s view_json|view|v [task_name] [option]

  Example:
      1. %s v              # show all task descriptions
      2. %s v [task_name]  # show one task description""" % (COMMAND, CMD, CMD),
                        arguments=['task_name'],
                        func=view_json.view)
program.action(cmd_view_json)




# add task
cmd_add_task = Command('add_task', alias=['atask'], description='add a task (%s) (%s)' % (PYTHON_PROJECT_ONLY, RUN_IN_PROJECT_FOLDER),
                       detail="add a task node into job.json, and create a promgram file in src folder.(%s) (%s)" % (PYTHON_PROJECT_ONLY, RUN_IN_PROJECT_FOLDER),
                       usage="""Usage: %s add_task|atask [task_name] [option]

  Examples:
      1. %s atask Map                                          #add a task named Map
      2. %s atask Map -d localhost:5000/myubuntu               #add a task named Map, use docker, you should tag you image using prefix:'localhost:5000/' first. if you forgot the port, type "docker ps" to see item named: registry_oss
      3. %s atask Map -i img-00000000561CB0FE000061CC00000411  #add a task named Map, and set image id
      4. %s atask Map -o oss://my-bucket/my-key/               # set oss oss_path""" % (COMMAND, CMD, CMD, CMD, CMD),
                       arguments=['task_name'],
                       func=add_task.add)
cmd_add_task.option('-i, --image_id [image_id]', 'set image_id for task, type "%s img" for more' % CMD,
                    resolve=update_task.transform_image_id)
cmd_add_task.option('-d, --docker_image [docker_image_name]', 'use docker image, type "docker images" for more')
cmd_add_task.option('-o, --oss_path [oss_path]', 'set oss path, and it will set value of PackageUri,StdoutRedirectPath and StderrRedirectPath',
                      resolve=update_task.transform_oss_path)
program.action(cmd_add_task)



# remove task
cmd_remove_task = Command('rm_task', alias=['rtask'], description='remove a task (%s) (%s)' % (PYTHON_PROJECT_ONLY,RUN_IN_PROJECT_FOLDER),
                          detail="remove a task node from job.json, and remove a promgram file from src folder.(%s) (%s)" % (PYTHON_PROJECT_ONLY,RUN_IN_PROJECT_FOLDER),
                          usage="""Usage: %s remove_task|rtask [task_name] [option]

  Examples:
      1. %s rtask Map  #remove a task named Map """ % (COMMAND, CMD),
                          arguments=['task_name'],
                          func=remove_task.remove)
cmd_remove_task.option('-y, --yes', 'without confirm')
program.action(cmd_remove_task)



# update task
cmd_update_task = Command('update_task', alias=['utask'], description='update a task (%s)' % (RUN_IN_PROJECT_FOLDER),
                       detail="update a task in job.json, if argument task_name is null, it will update properties for all tasks. (%s)" % (RUN_IN_PROJECT_FOLDER),
                       usage="""Usage: %s update_task|utask [task_name] [option]

  Examples:
      1. %s utask Map -d localhost:5000/myubuntu               # use docker
      2. %s utask Map -d false                                 # do not use docker
      3. %s utask Map -i img-00000000561CB0FE000061CC00000411  # set image id
      4. %s utask -i img-00000000561CB0FE000061CC00000411      # if task_name is null, set image id for all tasks
      5. %s utask Map -o oss://my-bucket/my-key/               # set oss oss_path for Map task""" % (COMMAND, CMD, CMD, CMD, CMD, CMD),
                       arguments=['task_name'],
                       func=update_task.update)
cmd_update_task.option('-i, --image_id [image_id]', 'set image_id for task, type "%s img" for more' % CMD,
                       resolve=update_task.transform_image_id)
cmd_update_task.option('-d, --docker_image [docker_image_name]', 'use docker image or not, type "docker images" to show avaliable docker_image_name, if set docker_image_name to false, this task will not use docker')
cmd_update_task.option('-o, --oss_path [oss_path]', 'set oss path, and it will update value of PackageUri,StdoutRedirectPath and StderrRedirectPath',
                      resolve=update_task.transform_oss_path)

program.action(cmd_update_task)




# add dependency
cmd_add_dep = Command('add_dep', alias=['ad'], description='add dependencies between tasks.(%s)' % RUN_IN_PROJECT_FOLDER,
                          detail="add dependencies to job.json.(%s)" % RUN_IN_PROJECT_FOLDER,
                          usage="""Usage: %s add_dep|ad [dep_pairs, multiple delimiters:','] [option]

  Examples:
      1. %s ad task1:task2             #add dependency: task1-->task2
      2. %s ad task1:task2,task3:task4 #add dependencies: task1-->task2 and task3-->task4 """ % (COMMAND, CMD, CMD),
                          arguments=['dep_pairs'],
                          func=add_dep.add)
program.action(cmd_add_dep)


# remove dependency
cmd_remove_dep = Command('rm_dep', alias=['rd'], description='remove dependencies between tasks.(%s)' % RUN_IN_PROJECT_FOLDER,
                          detail="remove dependencies from job.json.(%s)" % RUN_IN_PROJECT_FOLDER,
                          usage="""Usage: %s remove_dep|rd [dep_pairs, multiple delimiters:','] [option]

  Examples:
      1. %s rd task1:task2             #remove dependency: from task1 to task2
      2. %s rd task1:task2,task3:task4 #remove dependencies: from task1 to task2 , and from task3 to task4
      3. %s rd task1                   #remove dependencies from task1 to any other task""" % (COMMAND, CMD, CMD, CMD),
                           arguments=['dep_pairs'],
                          func=remove_dep.remove)
cmd_remove_dep.option('-y, --yes', 'without confirm')
program.action(cmd_remove_dep)




# debug
cmd_debug_task = Command('debug_task', alias=['debug'], description='debug task with docker image locally.(%s)' % RUN_IN_PROJECT_FOLDER,
                         usage="""Usage: %s debug [task_name] [docker_image] [option]

  Examples:
      1. %s debug Find myubuntu   # debug Find task, with local docker image: myubuntu""" % (COMMAND, CMD),
                         arguments=['task_name','docker_image'],
                         func=debug_task.debug)
program.action(cmd_debug_task)


def main():
    if os.getenv('DEBUG'):
         program.parse()
    else:
        try:
            program.parse()
        except Exception as e:
            print(red('\n  ERROR: %s\n' % format(e) ))

==> batchcomputecli-0.0.19.tar.gz: batchcomputecli-0.0.19/src/batchcomputecli/cli.py <==
from terminal import red, gray, bold, magenta, yellow
from .externals.command import Command
from .actions import login, whoami, images, jobs, job, update_job, \
    remove_job, start_job, stop_job, create_job, get_log, \
    submit_job

from .actions.project import create_project, build_project, \
    add_task, remove_task,update_task, debug_task, view_json,remove_dep, add_dep

import os
from . import const

COMMAND = const.COMMAND

CMD = const.CMD

VERSION = const.VERSION

SPLITER = '    %s' % ('-' * 50)

PYTHON_PROJECT_ONLY = red('python project only')

RUN_IN_PROJECT_FOLDER =  yellow('Run under project folder')

def __main():
    program.print_help()


program = Command(COMMAND, version=VERSION,
                  title=bold(magenta('AliCloud BatchCompute CLI')),
                  usage="Usage: %s <command> [option]" % COMMAND,
                  func=__main, help_footer=gray('  type "%s [command] -h" for more' % CMD))


# login
cmd_login = Command('login',
                    description='login with Aliyun AccessKey',
                    func=login.login,
                    arguments=['region', 'accessKeyId', 'accessKeySecret'],
                    usage='''Usage: %s login <region|endpoint> [accessKeyId] [accessKeySecret] [option]

  Examples:
     1. %s login cn-qingdao kywj6si2hkdfy9 lasd7f***********=  #login with full params
     2. %s login cn-shenzhen                                   #just change region
     3. %s login batchcompute.cn-shenzhen.aliyuncs.com         #just change endpoint''' % (COMMAND, CMD, CMD, CMD))
program.action(cmd_login)


# whoami
cmd_whoami = Command('me', alias=['who', 'whoami'], description='get login info',
                     detail='show accesskeyId, region or endpoint',
                     func=whoami.get, spliter=SPLITER)
program.action(cmd_whoami)

# images
cmd_images = Command('images', alias=['imgs', 'img'], description='list images', func=images.list)
cmd_images.option('-p, --platform [platform]', 'filter by platform, scope:[All|Linux|Windows],default:All',
                  resolve=images.transform_platform)
program.action(cmd_images)


# jobs
cmd_jobs = Command('jobs', description='list jobs', func=jobs.list)
cmd_jobs.option('-a, --all', 'show all fields')
cmd_jobs.option('-s, --state [state]',
                'filter by State, scope:[All|Waiting|Running|Failed|Finished|Stopped], default:All',
                resolve=jobs.transform_state)
cmd_jobs.option('-o, --order_by [field_name]', 'order by a field')
cmd_jobs.option('-d, --desc [true|false]', 'reverse result array, default: true')
cmd_jobs.option('-l, --limit [number]', 'limit the length of the result',
                resolve=jobs.transform_limit)
cmd_jobs.option('-w, --watch', 'in watching mode, auto refresh every 3 seconds')
program.action(cmd_jobs)

# job
cmd_job = Command('job', description='get job detail, task detail, instance logs',
                  arguments=['job_id', 'task_name', 'instance_id'],
                  usage="""Usage: %s job <job_id> [task_name] [instance_id] [option]

  Examples:
      1. %s job <job_id>                                         #job detail:
      2. %s job <job_id> <task_name>                             #task detail:
      3. %s job <job_id> <task_name> <instance_id> [--limit 10]  #instance log list: """ % (COMMAND, CMD, CMD, CMD),
                  func=job.getDetail)
cmd_job.option('-l, --limit [number]', 'limit the length of the result, only works in instance log list')
cmd_job.option('-w, --watch', 'in watching mode, auto refresh every 3 seconds, it works in job detail and task detail')
program.action(cmd_job)



# get_log
cmd_get_log = Command('get_log', alias=['log'], description='get instance log from oss_path',
                      spliter=SPLITER,
                      arguments=['oss_path'],
                      usage="""Usage: %s get_log <oss_path> [option]

  Examples:
      1. %s get_log oss://mybucket/abc/stdout.0.1443505842        #print log
      2. %s get_log oss://mybucket/abc/stdout.0.1443505842 -f ./  #download
                      """ % (COMMAND, COMMAND, COMMAND),
                      func=get_log.get_log)
cmd_get_log.option('-f, --file [directory or file]', 'download log to local: -f ./')
program.action(cmd_get_log)



# update_job
cmd_update_job = Command('update_job', alias=['update'],
                         description='update job properties, currently support "Priority" only',
                         arguments=['job_id'],
                         usage="Usage: %s update_job <job_id> [option]" % (COMMAND),
                         func=update_job.update_priority)
cmd_update_job.option('-p, --priority [n]', 'update job set priority, scope:[0,1000]',
                      resolve=update_job.transform_priority)
program.action(cmd_update_job)



# remove_job
cmd_remove_job = Command('remove_job', alias=['rm', 'remove'], description='remove a job',
                         arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=remove_job.remove)
cmd_remove_job.option('-y, --yes', 'without confirm', resolve=remove_job.transform_yes)
program.action(cmd_remove_job)


# start_job
cmd_start_job = Command('start_job', alias=['start'], description='start a job',
                        arguments=['job_id'],
                        # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                        func=start_job.start)
program.action(cmd_start_job)


# stop_job
cmd_stop_job = Command('stop_job', alias=['stop'], description='stop a job',
                       arguments=['job_id'],
                       # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                       func=stop_job.stop)
cmd_stop_job.option('-y, --yes', 'without confirm', resolve=stop_job.transform_yes)
program.action(cmd_stop_job)


# submit_job
cmd_create_job = Command('create_job', alias=['create'], description='create job, from a json string or file',
                         spliter=SPLITER,
                         # arguments=['job_id'],
                         # usage="Usage: %s remove_job <job_id> [option]" % (COMMAND),
                         func=create_job.create)

cmd_create_job.option('-j, --json [json_string]', 'create a job from a json string: -j "{\\"JobName\\":\"myJob...."',
                      resolve=create_job.transform_json)
cmd_create_job.option('-f, --file [file_path]', 'create a job from json file: -f ./myjob.json',
                      resolve=create_job.transform_file)
program.action(cmd_create_job)


#########################################
########################################

# def project_help():
#     cmd_project.print_help()
#
#
# # cmd_project
# cmd_project = Command('project', alias=['p'], description='project actions, type "bcs p -h" form more',
#                       detail="create, build job project, edit job...",
#                       func=project_help,help_footer=gray('  type "%s p [command] -h" for more' % CMD))
# program.action(cmd_project)



# create_project
cmd_create_project = Command('create_project', alias=['cp'], description='create job project',
                             detail='create job project',
                             arguments=['project_name', 'location'],
                             usage="""Usage: %s create_project|createp|cp <project_name> [location] [option]

  Examples:
    1. %s cp my_project                     # create an empty python type project
    2. %s cp my_project ./ -t java          # create an java type project with sample template
    3. %s cp my_project -j job-0000101010   # create a project from exists job, witch jobId is 'job-0000101010'""" % (COMMAND, CMD, CMD, CMD),
                             func=create_project.create)
cmd_create_project.option('-t, --type [template]', 'project type, scope:[python|java|native]',
                          resolve=create_project.transform_type)
cmd_create_project.option('-j, --job [job_id]', 'create project from exists job',
                          resolve=create_project.transform_job_id)
program.action(cmd_create_project)






# build_project
cmd_build_project = Command('build_project', alias=['build'],
                            detail='build project, make worker.tar.gz.(%s)' % RUN_IN_PROJECT_FOLDER,
                            description='build project, make worker.tar.gz.',
                            usage="""Usage: %s build_project|build [option]""" % (COMMAND),
                            func=build_project.build)
program.action(cmd_build_project)


# submit
cmd_submit_job = Command('submit_job', alias=['submit'], description='upload worker.tar.gz and create a job',
                         spliter=SPLITER,
                         detail="upload worker.tar.gz to PackageUri defined in job.json, and then create a job.(%s)" % RUN_IN_PROJECT_FOLDER,
                         usage="""Usage: %s submit_job|submit [option]

  Example: %s submit""" % (COMMAND, CMD),
                         func=submit_job.submit)
program.action(cmd_submit_job)


# view json
cmd_view_json = Command('view_json', alias=['view', 'v'],
                        description='show job.json in a humanized view.',
                        detail='show job.json in a humanized view.(%s)' % RUN_IN_PROJECT_FOLDER,
                        usage="""Usage: %s view_json|view|v [task_name] [option]

  Example:
      1. %s v                 # show job descriptions, dag, and all task description
      2. %s v -v              # show job descriptions, dag, and all task description, with validation information
      3. %s v -d              # show dag only
      4. %s v -t [task_name]  # show the task description""" % (COMMAND, CMD, CMD, CMD, CMD),
                        #arguments=['task_name'],
                        func=view_json.view)
cmd_view_json.option('-t, --task [task_name]', 'show description of a task',
                     resolve=view_json.transform_task)
cmd_view_json.option('-d, --dag_only', 'show dag only',
                     resolve=view_json.transform_task)
cmd_view_json.option('-v, --validate', 'validate json fields')
program.action(cmd_view_json)




# add task
cmd_add_task = Command('add_task', alias=['at'], description='add a task',
                       detail="add a task node into job.json, and create a promgram file in src folder.(%s)" % ( RUN_IN_PROJECT_FOLDER),
                       usage="""Usage: %s add_task|at [task_name] [option]

  Examples:
      1. %s at Map                                          #add a task named Map
      2. %s at Map -d localhost:5000/myubuntu               #add a task named Map, use docker, you should tag you image using prefix:'localhost:5000/' first. if you forgot the port, type "docker ps" to see item named: registry_oss
      3. %s at Map -i img-00000000561CB0FE000061CC00000411  #add a task named Map, and set image id
      4. %s at Map -o oss://my-bucket/my-key/               # set oss oss_path""" % (COMMAND, CMD, CMD, CMD, CMD),
                       arguments=['task_name'],
                       func=add_task.add)
cmd_add_task.option('-i, --image_id [image_id]', 'set image_id for task, type "%s img" for more' % CMD,
                    resolve=update_task.transform_image_id)
cmd_add_task.option('-d, --docker_image [docker_image_name]', 'use docker image, type "docker images" for more')
cmd_add_task.option('-o, --oss_path [oss_path]', 'set oss path, and it will set value of PackageUri,StdoutRedirectPath and StderrRedirectPath',
                      resolve=update_task.transform_oss_path)
program.action(cmd_add_task)



# remove task
cmd_remove_task = Command('rm_task', alias=['rt'], description='remove a task',
                          detail="remove tasks from job.json, and remove the promgram files from src folder. multiple task_name should seperated by ','.(%s)" % (RUN_IN_PROJECT_FOLDER),
                          usage="""Usage: %s remove_task|rt [task_name] [option]

  Examples:
      1. %s rt Map  #remove task: Map
      2. %s rt Map,Reduce  #remove tasks: Map and Reduce""" % (COMMAND, CMD, CMD),
                          arguments=['task_name'],
                          func=remove_task.remove)
cmd_remove_task.option('-y, --yes', 'without confirm')
program.action(cmd_remove_task)



# update task
cmd_update_task = Command('update_task', alias=['ut'], description='update a task',
                       detail="update a task in job.json, if argument task_name is null, it will update properties for all tasks. (%s)" % (RUN_IN_PROJECT_FOLDER),
                       usage="""Usage: %s update_task|ut [task_name] [option]

  Examples:
      1. %s ut Map -d localhost:5000/myubuntu                                         # use docker
      2. %s ut Map -d false                                                           # do not use docker
      3. %s ut Map -i img-00000000561CB0FE000061CC00000411                            # set image id
      4. %s ut -i img-00000000561CB0FE000061CC00000411                                # if task_name is null, set image id for all tasks
      5. %s ut Map -o oss://my-bucket/my-key/                                         # set oss oss_path for Map task
      6. %s ut Map -m oss://my-bucket/my-key/=/home/admin/d1,oss://my-bucket/my-key2/    # set OssMapping for Map task, add oss://my-bucket/my-key/ and remove oss://my-bucket/my-key2/""" % (COMMAND, CMD, CMD, CMD, CMD, CMD, CMD),
                       arguments=['task_name'],
                       func=update_task.update)
cmd_update_task.option('-i, --image_id [image_id]', 'set image_id for task, type "%s img" for more' % CMD,
                       resolve=update_task.transform_image_id)
cmd_update_task.option('-d, --docker_image [docker_image_name]', 'use docker image or not, type "docker images" to show avaliable docker_image_name, if set docker_image_name to false, this task will not use docker')
cmd_update_task.option('-o, --oss_path [oss_path]', 'set oss path, and it will update value of PackageUri,StdoutRedirectPath and StderrRedirectPath',
                      resolve=update_task.transform_oss_path)
cmd_update_task.option('-m, --mount [oss_mapping]', 'set OssMapping for task, format: [oss_path1=directory1,...], multiple pairs should seperated by ",". if you wanna remove a item, just set empty value like: oss_path1=')
program.action(cmd_update_task)




# add dependency
cmd_add_dep = Command('add_dep', alias=['ad'], description='add dependencies between tasks',
                          detail="add dependencies to job.json.(%s)" % RUN_IN_PROJECT_FOLDER,
                          usage="""Usage: %s add_dep|ad [dep_pairs, multiple delimiters:','] [option]

  Examples:
      1. %s ad task1:task2             #add dependency: task1-->task2
      2. %s ad task1:task2,task3:task4 #add dependencies: task1-->task2 and task3-->task4 """ % (COMMAND, CMD, CMD),
                          arguments=['dep_pairs'],
                          func=add_dep.add)
program.action(cmd_add_dep)


# remove dependency
cmd_remove_dep = Command('rm_dep', alias=['rd'], description='remove dependencies between tasks',
                          detail="remove dependencies from job.json.(%s)" % RUN_IN_PROJECT_FOLDER,
                          usage="""Usage: %s remove_dep|rd [dep_pairs, multiple delimiters:','] [option]

  Examples:
      1. %s rd task1:task2             #remove dependency: from task1 to task2
      2. %s rd task1:task2,task3:task4 #remove dependencies: from task1 to task2, and from task3 to task4
      3. %s rd task1                   #remove dependencies from task1 to any other task""" % (COMMAND, CMD, CMD, CMD),
                           arguments=['dep_pairs'],
                          func=remove_dep.remove)
cmd_remove_dep.option('-y, --yes', 'without confirm')
program.action(cmd_remove_dep)




# debug
cmd_debug_task = Command('debug_task', alias=['debug'],
                         description='debug task with docker image locally.',
                         detail='debug task with docker image locally.(%s)' % RUN_IN_PROJECT_FOLDER,
                         usage="""Usage: %s debug [task_name] [docker_image] [option]

  Examples:
      1. %s debug Find myubuntu                                                     # debug Find task, with local docker image: myubuntu
      2. %s debug Find myubuntu -m /home/local/:/home/admin/d1/,/home/local2/:/home/admin/d2/   # debug task, with mock OssMapping""" % (COMMAND, CMD, CMD),
                         arguments=['task_name','docker_image'],
                         func=debug_task.debug)
cmd_debug_task.option('-m, --mount [mock_oss_mapping]', 'mock OssMapping, replace oss_path to a local path. multiple pairs should seperated by ",".')
program.action(cmd_debug_task)


def main():
    if os.getenv('DEBUG'):
         program.parse()
    else:
        try:
            program.parse()
        except Exception as e:
            print(red('\n  ERROR: %s\n' % format(e) ))
